@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: close.h,v 1.13 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,13 +26,15 @@
 
 #include <glibtop.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
+
+void glibtop_close (void);
 
 void glibtop_close_r (glibtop *server);
 
 void glibtop_close_s (glibtop *server);
 void glibtop_close_p (glibtop *server);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
