@@ -1,4 +1,4 @@
-/* $Id: ppp.h,v 1.17 2004/06/09 18:52:20 bdejean Exp $ */
+/* $Id: ppp.h,v 1.19 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -51,7 +51,7 @@ struct _glibtop_ppp
 		bytes_out;		/* GLIBTOP_PPP_BYTES_OUT	*/
 };
 
-#define glibtop_get_ppp(ppp,device)	glibtop_get_ppp_l(glibtop_global_server, ppp, device)
+void glibtop_get_ppp(glibtop_ppp *buf, unsigned short device);
 
 #if GLIBTOP_SUID_PPP
 #define glibtop_get_ppp_r	glibtop_get_ppp_p
@@ -69,16 +69,6 @@ void glibtop_init_ppp_s (glibtop *server);
 void glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_ppp [];
-extern const unsigned glibtop_types_ppp [];
-extern const char *glibtop_labels_ppp [];
-extern const char *glibtop_descriptions_ppp [];
-
-#endif
 
 G_END_DECLS
 
