@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.c,v 1.17 2005/12/12 09:38:15 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,41 +21,45 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/cpu.h>
 #include <glibtop/uptime.h>
 
 #include <glibtop_suid.h>
 
+#include <time.h>
+
 static const unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
+(1 << GLIBTOP_UPTIME_UPTIME) + (1 << GLIBTOP_UPTIME_IDLETIME);
 
 /* Provides uptime and idle time. */
 
-int
+void
 glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 {
-    glibtop_cpu cpu;
+	glibtop_cpu cpu;
 
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_UPTIME), 0);
 
-    /* Get currect cpu usage. */
+	/* Get currect cpu usage. */
 
-    glibtop_get_cpu_p (server, &cpu);
+	glibtop_get_cpu_p (server, &cpu);
 
-    /* Make sure all required fields are present. */
+	/* Make sure all required fields are present. */
 
-    if (((cpu.flags & (1L << GLIBTOP_CPU_TOTAL)) == 0) ||
-	((cpu.flags & (1L << GLIBTOP_CPU_IDLE)) == 0) ||
-	((cpu.flags & (1L << GLIBTOP_CPU_FREQUENCY)) == 0) ||
-	(cpu.frequency == 0))
-	return;
+	if (((cpu.flags & (1 << GLIBTOP_CPU_TOTAL)) == 0) ||
+	    ((cpu.flags & (1 << GLIBTOP_CPU_IDLE)) == 0) ||
+	    ((cpu.flags & (1 << GLIBTOP_CPU_FREQUENCY)) == 0) ||
+	    (cpu.frequency == 0))
+		return;
 
-    /* Simply calculate uptime and idle time from
-     * cpu usage. */
+	/* Simply calculate uptime and idle time from
+	 * cpu usage. */
 
-    buf->uptime = (double) cpu.total / (double) cpu.frequency;
-    buf->idletime = (double) cpu.idle / (double) cpu.frequency;
+	buf->uptime = (double) cpu.total / (double) cpu.frequency;
+	buf->idletime = (double) cpu.idle / (double) cpu.frequency;
+	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
 
-    buf->flags = _glibtop_sysdeps_uptime;
+	buf->flags = _glibtop_sysdeps_uptime;
 }
